summaryrefslogtreecommitdiffstats
path: root/chrome/browser/gtk/menu_gtk.h
diff options
context:
space:
mode:
authorestade@chromium.org <estade@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-03-09 19:21:21 +0000
committerestade@chromium.org <estade@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2009-03-09 19:21:21 +0000
commit1d78e832493c2b6f27cdf50a7ad6bfcd65c6e206 (patch)
tree26ea2ce939e982135b14670f30f751c903afd1bd /chrome/browser/gtk/menu_gtk.h
parentc557bc0c37f16d49d95ff46eb5691895007cc241 (diff)
downloadchromium_src-1d78e832493c2b6f27cdf50a7ad6bfcd65c6e206.zip
chromium_src-1d78e832493c2b6f27cdf50a7ad6bfcd65c6e206.tar.gz
chromium_src-1d78e832493c2b6f27cdf50a7ad6bfcd65c6e206.tar.bz2
Implement right click context menu on gtk.
Review URL: http://codereview.chromium.org/40266 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@11271 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser/gtk/menu_gtk.h')
-rw-r--r--chrome/browser/gtk/menu_gtk.h9
1 files changed, 7 insertions, 2 deletions
diff --git a/chrome/browser/gtk/menu_gtk.h b/chrome/browser/gtk/menu_gtk.h
index 6dd1d05..d55a8be 100644
--- a/chrome/browser/gtk/menu_gtk.h
+++ b/chrome/browser/gtk/menu_gtk.h
@@ -45,12 +45,17 @@ class MenuGtk {
explicit MenuGtk(MenuGtk::Delegate* delegate);
~MenuGtk();
// Displays the menu. |timestamp| is the time of activation.
void Popup(GtkWidget* widget, gint button_type, guint32 timestamp);
// Displays the menu using the button type and timestamp of |event|.
void Popup(GtkWidget* widget, GdkEvent* event);
+ // Displays the menu as a context menu, i.e. at the current cursor location.
+ void PopupAsContext();
+
private:
// A recursive function that transforms a MenuCreateMaterial tree into a set
// of GtkMenuItems.
@@ -45,12 +45,17 @@ class MenuGtk {
explicit MenuGtk(MenuGtk::Delegate* delegate);
~MenuGtk();
- // Displays the menu. |timestamp| is the time of activation.
+ // Displays the menu. |timestamp| is the time of activation. The popup is
+ // statically positioned at |widget|.
void Popup(GtkWidget* widget, gint button_type, guint32 timestamp);
@@ -45,12 +45,17 @@ class MenuGtk {
void Popup(GtkWidget* widget, gint button_type, guint32 timestamp);
- // Displays the menu using the button type and timestamp of |event|.
+ // Displays the menu using the button type and timestamp of |event|. The popup
+ // is statically positioned at |widget|.
void Popup(GtkWidget* widget, GdkEvent* event);